abjadbooktools.OutputFormat
===========================

.. inheritance-diagram:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat
   :private-bases:

.. autoclass:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_block_closing

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_block_opening

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.code_indent

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.image_block

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.image_format

.. autoattribute:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__call__

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.OutputFormat.OutputFormat.OutputFormat.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
